==> maven-settings-2.0.8-sources.jar: org/apache/maven/settings/Repository.java <==
/*
 * $Id$
 */

package org.apache.maven.settings;

/**
 * 
 *         Repository contains the information needed for
 * establishing
 *         connections with remote repoistory
 *       
 * 
 * @version $Revision$ $Date$
 */
public class Repository extends RepositoryBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field releases
     */
    private RepositoryPolicy releases;

    /**
     * Field snapshots
     */
    private RepositoryPolicy snapshots;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get 
     *             How to handle downloading of releases from this
     * repository
     *           
     */
    public RepositoryPolicy getReleases()
    {
        return this.releases;
    } //-- RepositoryPolicy getReleases() 

    /**
     * Get 
     *             How to handle downloading of snapshots from this
     * repository
     *           
     */
    public RepositoryPolicy getSnapshots()
    {
        return this.snapshots;
    } //-- RepositoryPolicy getSnapshots() 

    /**
     * Set 
     *             How to handle downloading of releases from this
     * repository
     *           
     * 
     * @param releases
     */
    public void setReleases(RepositoryPolicy releases)
    {
        this.releases = releases;
    } //-- void setReleases(RepositoryPolicy) 

    /**
     * Set 
     *             How to handle downloading of snapshots from this
     * repository
     *           
     * 
     * @param snapshots
     */
    public void setSnapshots(RepositoryPolicy snapshots)
    {
        this.snapshots = snapshots;
    } //-- void setSnapshots(RepositoryPolicy) 


            
    /**
     * @see org.apache.maven.settings.RepositoryBase#equals(java.lang.Object)
     */
    public boolean equals( Object obj )
    {
        return super.equals( obj );
    }
            
          
    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }}

==> maven-settings-2.0.11-sources.jar: org/apache/maven/settings/Repository.java <==
/*
 * $Id$
 */

package org.apache.maven.settings;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * 
 *         Repository contains the information needed for
 * establishing
 *         connections with remote repoistory
 *       .
 * 
 * @version $Revision$ $Date$
 */
public class Repository extends RepositoryBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * 
     *             How to handle downloading of releases from this
     * repository
     *           .
     */
    private RepositoryPolicy releases;

    /**
     * 
     *             How to handle downloading of snapshots from this
     * repository
     *           .
     */
    private RepositoryPolicy snapshots;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get 
     *             How to handle downloading of releases from this
     * repository
     *           .
     * 
     * @return RepositoryPolicy
     */
    public RepositoryPolicy getReleases()
    {
        return this.releases;
    } //-- RepositoryPolicy getReleases() 

    /**
     * Get 
     *             How to handle downloading of snapshots from this
     * repository
     *           .
     * 
     * @return RepositoryPolicy
     */
    public RepositoryPolicy getSnapshots()
    {
        return this.snapshots;
    } //-- RepositoryPolicy getSnapshots() 

    /**
     * Set 
     *             How to handle downloading of releases from this
     * repository
     *           .
     * 
     * @param releases
     */
    public void setReleases( RepositoryPolicy releases )
    {
        this.releases = releases;
    } //-- void setReleases( RepositoryPolicy ) 

    /**
     * Set 
     *             How to handle downloading of snapshots from this
     * repository
     *           .
     * 
     * @param snapshots
     */
    public void setSnapshots( RepositoryPolicy snapshots )
    {
        this.snapshots = snapshots;
    } //-- void setSnapshots( RepositoryPolicy ) 


            
    /**
     * @see org.apache.maven.settings.RepositoryBase#equals(java.lang.Object)
     */
    public boolean equals( Object obj )
    {
        return super.equals( obj );
    }
            
          
    private String modelEncoding = "UTF-8";

    /**
     * Set an encoding used for reading/writing the model.
     *
     * @param modelEncoding the encoding used when reading/writing the model.
     */
    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    /**
     * @return the current encoding used when reading/writing this model.
     */
    public String getModelEncoding()
    {
        return modelEncoding;
    }
}
